@@ -6,7 +6,7 @@
 
 #include "chemicaldataobject.h"
 
-#include <QDebug>
+#include "kalzium_libscience_debug.h"
 #include <QLatin1String>
 
 #include <KUnitConversion/Converter>
