@@ -325,7 +325,7 @@ void Kalzium::slotGlossary()
       // creating the glossary dialog and loading the glossaries we have
       m_glossarydlg = new GlossaryDialog(this);
       m_glossarydlg->setObjectName(QStringLiteral("glossary"));
-      QString dir = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("data/"), QStandardPaths::LocateDirectory);
+      QString dir = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/"), QStandardPaths::LocateDirectory);
       dir = QFileInfo(dir).absolutePath();
       QString picturepath = dir + "/bg.jpg";
       QUrl u = QUrl::fromLocalFile(dir + "/knowledge.xml");
@@ -434,14 +434,14 @@ void Kalzium::slotSwitchtoTable(int index)
 
 void Kalzium::slotSwitchtoNumeration(int index)
 {
-    emit numerationChanged(index);
+    Q_EMIT numerationChanged(index);
     Prefs::setNumeration(index);
     Prefs::self()->save();
 }
 
 void Kalzium::slotSwitchtoLookGradient(int which)
 {
-    qDebug() << "slotSwitchtoLookGradient Kalzium";
+    qCDebug(KALZIUM_LOG) << "slotSwitchtoLookGradient Kalzium";
 
     KalziumElementProperty::instance()->setGradient(which);
 
@@ -461,7 +461,7 @@ void Kalzium::slotSwitchtoLookGradient(int which)
 
 void Kalzium::slotSwitchtoLookScheme(int which)
 {
-    qDebug() << "slotSwitchtoLookScheme Kalzium";
+    qCDebug(KALZIUM_LOG) << "slotSwitchtoLookScheme Kalzium";
 
     KalziumElementProperty::instance()->setScheme(which);
 
@@ -558,7 +558,7 @@ void Kalzium::elementHover(int num)
                                  e->dataAsString(ChemicalDataObject::name),
                                  e->dataAsString(ChemicalDataObject::atomicNumber),
                                  e->dataAsString(ChemicalDataObject::mass)));
-    qDebug() << "change item in status bar";
+    qCDebug(KALZIUM_LOG) << "change item in status bar";
 
     m_detailWidget->setElement(num);
 }
@@ -567,7 +567,7 @@ void Kalzium::elementHover(int num)
 void Kalzium::extractIconicInformationAboutElement(int elementNumber)
 {
     QString setname = QStringLiteral("school");
-    QString pathname = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
+    QString pathname = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
     pathname = QFileInfo(pathname).absolutePath();
     QString filename = pathname + setname + '/' + "iconinformation.txt";
 
